@@ -1,4 +1,5 @@
 package Devel::ebug::Backend::Plugin::Run;
+$Devel::ebug::Backend::Plugin::Run::VERSION = '0.56';
 use strict;
 use warnings;
 
@@ -7,7 +8,6 @@ sub register_commands {
       next        => { sub => \&next, record => 1 },
       return      => { sub => \&return, record => 1 },
       run         => { sub => \&run, record => 1 },
-      return      => { sub => \&return, record => 1 },      
       step        => { sub => \&step, record => 1 },
     );
 }
@@ -19,9 +19,6 @@ sub next {
   return {};
 }
 
-
-
-
 sub return {
   my($req, $context) = @_;
   if ($req->{values}) {
